@@ -3,17 +3,19 @@ package Unix::Uptime;
 use warnings;
 use strict;
 
-our $VERSION='0.3';
+our $VERSION='0.32';
+$VERSION = eval $VERSION;
 
 my %modules = (
     freebsd => 'FreeBSD',
     linux   => 'Linux',
     openbsd => 'BSD',
     darwin  => 'BSD',
+    netbsd  => 'BSD',
 );
 
 my $module = $modules{$^O}
-    or die "Operating system type $^O is currently unupported";
+    or die "Operating system type $^O is currently unsupported";
 
 require "Unix/Uptime/$module.pm";
 our @ISA = ("Unix::Uptime::$module");
@@ -48,7 +50,7 @@ different *NIX architectures
 
   # Standard Usage
   use Unix::Uptime;
-  
+
   my $uptime = Unix::Uptime->uptime(); # 2345
 
   # "HiRes" mode
@@ -64,15 +66,17 @@ this on non-Linux systems, without SNMP. If you want to use SNMP, there
 are pleanty of modules on CPAN already.
 
 Currently, this module just supports getting the uptime on Linux,
-FreeBSD, Darwin (Mac OS X), and OpenBSD. It should be easy enough to add
+FreeBSD, Darwin (Mac OS X), OpenBSD, and NetBSD. It should be easy enough to add
 support for other operating systems, though.
 
 =head1 OPTIONS
 
 While this module doesn't provide any functions for exporting, if the
-tag C<:hires> is given, then the times returned will be returned as
-decimal numbers when possible. This will likely require the Time::HiRes
-module to be available. Otherwise, they will simply be whole seconds.
+tag C<:hires> is given, then uptime_hires static method will be
+available. It returns decimal numbers when possible, but on some systems
+it is simply an alias for C<uptime()>. This will likely
+require the Time::HiRes module to be available. Otherwise, they will
+simply be whole seconds.
 
 =head1 METHODS
 
@@ -81,15 +85,31 @@ The following static (class) methods are available:
 =head2 uptime()
 
 This takes no arguments, and simply returns the number of seconds this
-system has been running. Depending on the operating system, this could
-be a whole integer, or a floating point number.
+system has been running. This will always be an integer.
 
 =head2 uptime_hires()
 
 This is only available if the C<:hires> import tag is used. It returns
 the system uptime with a greater resolution than one second on supported
 platforms. On some platforms, its results may not be any more precise
-than C<uptime()>, though.
+than C<uptime()>, though. On different platforms, this requires
+different additional modules:
+
+=over 4
+
+=item Linux
+
+No additional requirements.
+
+=item FreeBSD
+
+Requires Time::HiRes
+
+=item Darwin, OpenBSD, NetBSD
+
+No more precise than uptime()
+
+=back
 
 =head1 SEE ALSO
 
@@ -99,8 +119,15 @@ L<Win32::Uptime> for Win32.
 
 =head1 BUGS
 
-This currently doesn't support more than Linux and FreeBSD.
-Contributions for other operating systems would be welcome.
+This currently doesn't support more than Linux, FreeBSD, Darwin (Mac OS
+X), OpenBSD, and NetBSD. Contributions for other operating systems would
+be welcome.
+
+=head1 CAVEATS
+
+B<NOTE:> This module is still a work in progress, under fairly heavy
+development.  While I think the final API should be mostly finalized at
+this point, I won't commit to an API freeze until version 1.0.
 
 =head1 CONTRIBUTING
 
@@ -108,7 +135,8 @@ This project is developed using git. The repository may be browsed at:
 L<http://git.pioto.org/gitweb/Unix-Uptime.git>
 
 Patches in git-format-patch style are preferred. Either send them to me
-by email, or open an RT ticket.
+by email, or open an RT ticket
+L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Unix-Uptime>.
 
 =head1 AUTHOR
 
