@@ -3,19 +3,23 @@ package Unix::Uptime::BSD;
 use warnings;
 use strict;
 
-use DateTime;
+our $VERSION='0.32';
+$VERSION = eval $VERSION;
+
 use DateTime::Format::Strptime;
 
 sub uptime {
     my $class = shift;
 
-    my $boottime = `sysctl kern.boottime`;
+    my $boottime = `/sbin/sysctl kern.boottime`;
 
     $boottime =~ s/^\s*kern\.boottime\s*=\s*//;
     # OpenBSD:
     #   kern.boottime=Mon Jan  5 14:00:50 2009
     # Darwin:
     #   kern.boottime = Wed Jan 21 12:49:52 2009
+    # NetBSD:
+    #   kern.boottime = Mon Jan  5 15:30:35 2009
     my $strp = DateTime::Format::Strptime->new(
         pattern => '%a%t%b%t%d%t%T%t%Y',
     );
@@ -27,3 +31,18 @@ sub uptime {
 no warnings qw(once);
 *uptime_hires = \&uptime;
 
+1;
+
+__END__
+
+=head1 NAME
+
+Unix::Uptime::BSD - BSD implementation of Unix::Uptime (for Darwin, OpenBSD, and NetBSD)
+
+=head1 SEE ALSO
+
+L<Unix::Uptime>
+
+=cut
+
+# vim: set ft=perl sw=4 sts=4 et :
