@@ -1,5 +1,11 @@
 package Unix::Uptime::Linux;
 
+use warnings;
+use strict;
+
+our $VERSION='0.32';
+$VERSION = eval $VERSION;
+
 sub uptime {
     my $class = shift;
     open my $proc_uptime, '<', '/proc/uptime'
@@ -26,3 +32,17 @@ sub uptime_hires {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Unix::Uptime::Linux - Linux implementation of Unix::Uptime
+
+=head1 SEE ALSO
+
+L<Unix::Uptime>
+
+=cut
+
+# vim: set ft=perl sw=4 sts=4 et :
